==> dnet-openaireplus-workflows-1.0.0-20140305.172725-1-sources.jar: eu/dnetlib/msro/openaireplus/workflows/nodes/index/IndexDSUpdateJobNode.java <==
package eu.dnetlib.msro.openaireplus.workflows.nodes.index;

import javax.annotation.Resource;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.googlecode.sarasvati.Arc;
import com.googlecode.sarasvati.NodeToken;

import eu.dnetlib.enabling.is.registry.rmi.ISRegistryException;
import eu.dnetlib.enabling.is.registry.rmi.ISRegistryService;
import eu.dnetlib.enabling.tools.ServiceLocator;
import eu.dnetlib.msro.workflows.nodes.AsyncJobNode;

public class IndexDSUpdateJobNode extends AsyncJobNode {

	private static final Log log = LogFactory.getLog(IndexDSUpdateJobNode.class); // NOPMD by marko on 11/24/08 5:02 PM

	public final static String N_RECORDS_PARAM = "blackboard:param:index.status code: 0";

	@Resource
	private ServiceLocator<ISRegistryService> registryLocator;

	@Override
	public String execute(final NodeToken token) throws Exception {

		final String dsId = token.getEnv().getAttribute("index_id");
		final String version = token.getEnv().getAttribute("index.feed.timestamp");

		try {
			final int count = Integer.parseInt(token.getEnv().getAttribute(N_RECORDS_PARAM));
			log.info("updating indexDS: " + dsId + " version: " + version + " record count: " + count);
			updateIndexDS(dsId, version, count);
		} catch (NumberFormatException e) {
			log.warn("unable to find index feeding details in the workflow env, skippind DS update");
		}

		return Arc.DEFAULT_ARC;
	}

	/**
	 * method updates the given indexDataStructureId INDEX_SIZE, INDEX_LAST_UPDATE
	 * 
	 * @param dsId
	 * @param size
	 * @return true if the update was performed successfully, false otherwise
	 * @throws ISRegistryException
	 */
	private boolean updateIndexDS(final String dsId, final String version, final long count) throws ISRegistryException {

		final String xquery = "for $x in collection('')/RESOURCE_PROFILE[.//RESOURCE_IDENTIFIER/@value = '" + dsId + "']"
				+ " return update value $x//INDEX_SIZE with " + String.valueOf(count) + ","
				+ "for $x in collection('')/RESOURCE_PROFILE[.//RESOURCE_IDENTIFIER/@value = '" + dsId + "']"
				+ " return update value $x//INDEX_LAST_UPDATE with '" + version + "' ";

		log.debug("\n\n updating indexDataStructure: " + xquery + "\n\n");

		return registryLocator.getService().executeXUpdate(xquery);
	}

}

==> dnet-openaireplus-workflows-2.0.1-20141114.113430-1-sources.jar: eu/dnetlib/msro/openaireplus/workflows/nodes/index/IndexDSUpdateJobNode.java <==
package eu.dnetlib.msro.openaireplus.workflows.nodes.index;

import javax.annotation.Resource;

import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

import com.googlecode.sarasvati.Arc;
import com.googlecode.sarasvati.NodeToken;

import eu.dnetlib.enabling.is.registry.rmi.ISRegistryException;
import eu.dnetlib.enabling.is.registry.rmi.ISRegistryService;
import eu.dnetlib.enabling.locators.UniqueServiceLocator;
import eu.dnetlib.msro.workflows.nodes.AsyncJobNode;

public class IndexDSUpdateJobNode extends AsyncJobNode {

	private static final Log log = LogFactory.getLog(IndexDSUpdateJobNode.class); // NOPMD by marko on 11/24/08 5:02 PM

	public final static String N_RECORDS_PARAM = "blackboard:param:index.status code: 0";

	@Resource
	private UniqueServiceLocator serviceLocator;

	@Override
	public String execute(final NodeToken token) throws Exception {

		final String dsId = token.getEnv().getAttribute("index_id");
		final String version = token.getEnv().getAttribute("index.feed.timestamp");

		try {
			final int count = Integer.parseInt(token.getEnv().getAttribute(N_RECORDS_PARAM));
			log.info("updating indexDS: " + dsId + " version: " + version + " record count: " + count);
			updateIndexDS(dsId, version, count);
		} catch (NumberFormatException e) {
			log.warn("unable to find index feeding details in the workflow env, skippind DS update");
		}

		return Arc.DEFAULT_ARC;
	}

	/**
	 * method updates the given indexDataStructureId INDEX_SIZE, INDEX_LAST_UPDATE
	 * 
	 * @param dsId
	 * @param size
	 * @return true if the update was performed successfully, false otherwise
	 * @throws ISRegistryException
	 */
	private boolean updateIndexDS(final String dsId, final String version, final long count) throws ISRegistryException {

		final String xquery = "for $x in collection('')/RESOURCE_PROFILE[.//RESOURCE_IDENTIFIER/@value = '" + dsId + "']"
				+ " return update value $x//INDEX_SIZE with " + String.valueOf(count) + ","
				+ "for $x in collection('')/RESOURCE_PROFILE[.//RESOURCE_IDENTIFIER/@value = '" + dsId + "']"
				+ " return update value $x//INDEX_LAST_UPDATE with '" + version + "' ";

		log.debug("\n\n updating indexDataStructure: " + xquery + "\n\n");

		return serviceLocator.getService(ISRegistryService.class).executeXUpdate(xquery);
	}

}
